# SnakeCan

SnakeCan is a subset of essential UNIX command-line tools, implementated in Python.  The goal of SnakeCan is to create a light-weight and simple cross-platform environment that runs smoothly Windows, Linux, or anywhere Python can be found. While not aiming to replace existing implementations of these utilities, SnakeCan offers a standardized toolbox for automation tasks across different operating systems.

